﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Net;
using System.Threading.Tasks;
using System.Xml.Linq;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;

namespace GridViewLiveTiles.Data
{
    public class FlickrPhoto : C1.Xaml.Tile.ILoadable
    {
        public string Tag { get; set; }
        public string Title { get; set; }
        public string Thumbnail { get; set; }
        public string Content { get; set; }
        public string Author { get; set; }
        public ImageSource ImageSource { get; private set; }
        public int TileWidth { get; set; }

        #region ** ILoadable implementation
        public bool IsLoaded
        {
            get { return _isLoaded; }
        }
        private bool _isLoaded = false;

        public bool Load()
        {
            if (!_isLoaded && !string.IsNullOrEmpty(Thumbnail))
            {
                BitmapImage img = new BitmapImage(new System.Uri(Thumbnail));
                img.ImageOpened += (s, e) =>
                {
                    _isLoaded = true;
                };
                img.ImageFailed += (s, e) =>
                {
                    _isLoaded = true;
                };
                ImageBrush image = new ImageBrush();
                image.ImageSource = img;
                ImageSource = img;
            }
            return _isLoaded;
        }
        #endregion

    }

    public class FlickrCategory
    {

        static string flickrUrl = "http://api.flickr.com/services/feeds/photos_public.gne";
        static string AtomNS = "http://www.w3.org/2005/Atom";

        private int _tileWidth = 1;

        public FlickrCategory(string tag, int tileWidth = 1)
        {
            _tileWidth = tileWidth;
            Id = tag;
            Items = new ObservableCollection<FlickrPhoto>();
        }

        public string Id
        {
            get;
            set;
        }
        public ObservableCollection<FlickrPhoto> Items { get; set; }

        /// <summary>
        /// Loads public photos from flickr.
        /// </summary>
        /// <param name="tag">If set, method uses it to load photos only with this specific tag.</param>
        /// <returns></returns>
        public async Task<ObservableCollection<FlickrPhoto>> Load()
        {
            try
            {
                string uri = string.IsNullOrEmpty(Id) ? flickrUrl : flickrUrl + "?tags=" + Id;
                var client = WebRequest.CreateHttp(uri);
                var response = await client.GetResponseAsync();

                #region ** parse flickr data
                using (System.IO.Stream stream = response.GetResponseStream())
                {
                    var doc = XDocument.Load(stream);
                    foreach (var entry in doc.Descendants(XName.Get("entry", AtomNS)))
                    {
                        var title = entry.Element(XName.Get("title", AtomNS)).Value;
                        var author = entry.Element(XName.Get("author", AtomNS)).Element(XName.Get("name", AtomNS)).Value;
                        var enclosure = entry.Elements(XName.Get("link", AtomNS)).Where(elem => elem.Attribute("rel").Value == "enclosure").FirstOrDefault();
                        var contentUri = enclosure.Attribute("href").Value;
                        Items.Add(new FlickrPhoto() { Title = title, Tag = Id, TileWidth = _tileWidth, Content = contentUri, Thumbnail = contentUri.Replace("_b", "_m"), Author = author });
                        if (Items.Count > 7)
                        {
                            break;
                        }
                    }
                }
                #endregion
            }
            catch
            {
            }
            return Items;
        }
    }
}
