﻿using C1.Xaml.Tile;
using GridViewLiveTiles.Data;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace GridViewLiveTiles
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        public double TileSize
        {
            get { return (double)GetValue(TileSizeProperty); }
            set { SetValue(TileSizeProperty, value); }
        }

        public static readonly DependencyProperty TileSizeProperty =
            DependencyProperty.Register("TileSize", typeof(double), typeof(MainPage), new PropertyMetadata(150));

        List<FlickrCategory> _groups = new List<FlickrCategory>();

        public MainPage()
        {
            if (Windows.Foundation.Metadata.ApiInformation.IsTypePresent("Windows.Phone.UI.Input.HardwareButtons"))
            {
                TileSize = 76;
            }
            _groups.Add(new FlickrCategory("Nature"));
            _groups.Add(new FlickrCategory("People", 2));
            _groups.Add(new FlickrCategory("Travel"));
            _groups.Add(new FlickrCategory("Night", 2));
            _groups.Add(new FlickrCategory("Traffic"));
            _groups.Add(new FlickrCategory("Arch", 2));
            _groups.Add(new FlickrCategory("Animals"));
            _groups.Add(new FlickrCategory("Cars"));
            _groups.Add(new FlickrCategory("Family"));
            _groups.Add(new FlickrCategory("Summer"));

            this.InitializeComponent();

            CollectionViewSource source = new CollectionViewSource();
            source.Source = _groups;
            source.ItemsPath = new PropertyPath("Items");
            source.IsSourceGrouped = true;
            this.DataContext = source;
        }

        private async void LoadContent()
        {
            gve.Visibility = Visibility.Collapsed;
            loading.Visibility = Visibility.Visible;
            BottomAppBar.Visibility = Visibility.Collapsed;
            try
            {
                foreach (FlickrCategory category in _groups)
                {
                    await category.Load();
                    loading.Visibility = Visibility.Collapsed;
                    gve.Visibility = Visibility.Visible;
                }
            }
            catch
            {
                var dialog = new Windows.UI.Popups.MessageDialog("There was an error when attempting to download data from Flickr.");
                dialog.ShowAsync();
                loading.Visibility = Visibility.Collapsed;
            }
            BottomAppBar.Visibility = Visibility.Visible;
        }

        private void OnLoaded(object sender, RoutedEventArgs e)
        {
            LoadContent();
        }

        private void Grid_Tapped(object sender, TappedRoutedEventArgs e)
        {
            FrameworkElement el = e.OriginalSource as FrameworkElement;
            if (el != null && el.DataContext is FlickrPhoto)
            {
                // open clicked image in browser
                var uri = new Uri(((FlickrPhoto)(el.DataContext)).Content);
                Windows.System.Launcher.LaunchUriAsync(uri);
            }
        }

        private void gve_PreparingContainerForItem(object sender, GridViewEx.PreparingContainerForItemEventArgs e)
        {
            // set column span according to the current group
            FlickrPhoto fp = e.Item as FlickrPhoto;
            if (fp != null && fp.TileWidth == 2)
            {
                e.Element.SetValue(Windows.UI.Xaml.Controls.VariableSizedWrapGrid.ColumnSpanProperty, 2);
            }
        }
    }
}
